smf/smfservermodule/smfserver/smfplugins/smfcontactfetcherplugin.h
changeset 25 a180113055cb
parent 14 a469c0e6e7fb
--- a/smf/smfservermodule/smfserver/smfplugins/smfcontactfetcherplugin.h	Thu Sep 23 17:20:22 2010 +0530
+++ b/smf/smfservermodule/smfserver/smfplugins/smfcontactfetcherplugin.h	Thu Sep 23 17:43:31 2010 +0530
@@ -46,9 +46,10 @@
 	/**
 	 * Method to get the list of friends
 	 * @param aRequest [out] The request data to be sent to network
-	 * @param aPageNum The page to be extracted
-	 * @param aItemsPerPage Number of items per page
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @param aPageNum [in] The page to be extracted
+	 * @param aItemsPerPage [in] Number of items per page
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError friends( SmfPluginRequestData &aRequest,
 			const int aPageNum = SMF_FIRST_PAGE, 
@@ -57,21 +58,23 @@
 	/**
 	 * Method to get the list of followers
 	 * @param aRequest [out] The request data to be sent to network
-	 * @param aPageNum The page to be extracted
-	 * @param aItemsPerPage Number of items per page
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @param aPageNum [in] The page to be extracted
+	 * @param aItemsPerPage [in] Number of items per page
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError followers( SmfPluginRequestData &aRequest,
 			const int aPageNum = SMF_FIRST_PAGE, 
 			const int aItemsPerPage = SMF_ITEMS_PER_PAGE ) = 0;
 	
 	/**
-	 * Method to search for a contact
+	 * Method to search for a contact (name or service ID should be provided)
 	 * @param aRequest [out] The request data to be sent to network
-	 * @param aContact contact to be searched
-	 * @param aPageNum The page to be extracted
-	 * @param aItemsPerPage Number of items per page
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @param aContact [in] contact to be searched
+	 * @param aPageNum [in] The page to be extracted
+	 * @param aItemsPerPage [in] Number of items per page
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError search( SmfPluginRequestData &aRequest,
 			const SmfContact &aContact,
@@ -82,11 +85,12 @@
 	 * Method to search for contacts (friends) who are near the user.
 	 * Proximity defines accuracy level
 	 * @param aRequest [out] The request data to be sent to network
-	 * @param aLocation The location search criteria
-	 * @param aProximity location search boundary
-	 * @param aPageNum The page to be extracted
-	 * @param aItemsPerPage Number of items per page
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @param aLocation [in] The location search criteria
+	 * @param aProximity [in] location search boundary
+	 * @param aPageNum [in] The page to be extracted
+	 * @param aItemsPerPage [in] Number of items per page
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError searchNear( SmfPluginRequestData &aRequest,
 			const SmfLocation &aLocation,
@@ -99,7 +103,8 @@
 	 * @param aRequest [out] The request data to be sent to network
 	 * @param aPageNum The page to be extracted
 	 * @param aItemsPerPage Number of items per page
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError groups( SmfPluginRequestData &aRequest,
 			const int aPageNum = SMF_FIRST_PAGE, 
@@ -108,24 +113,29 @@
 	/**
 	 * Method to search for a contact in a group
 	 * @param aRequest [out] The request data to be sent to network
 	 * @param aGroup the group in which to search
 	 * @param aPageNum The page to be extracted
 	 * @param aItemsPerPage Number of items per page
 	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
 	 */
 	virtual SmfPluginError searchInGroup( SmfPluginRequestData &aRequest,
 			const SmfGroup &aGroup,
+			SmfContact *aContact = NULL,
 			const int aPageNum = SMF_FIRST_PAGE, 
 			const int aItemsPerPage = SMF_ITEMS_PER_PAGE ) = 0;
 	
 	/**
 	 * Customised method for SmfContactFetcherPlugin interface
 	 * @param aRequest [out] The request data to be sent to network
-	 * @param aOperation The operation type (should be known between 
+	 * @param aOperation [in] The operation type (should be known between 
 	 * the client interface and the plugin)
-	 * @param aData The data required to form the request (The type 
+	 * @param aData [in] The data required to form the request (The type 
 	 * of data should be known between client and the plugin)
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError customRequest( SmfPluginRequestData &aRequest, 
 			const int &aOperation, QByteArray *aData ) = 0;
@@ -108,24 +113,29 @@
 	 * Method to search for a contact in a group
 	 * @param aRequest [out] The request data to be sent to network
-	 * @param aGroup the group in which to search
-	 * @param aPageNum The page to be extracted
-	 * @param aItemsPerPage Number of items per page
-	 * @return SmfPluginError Plugin error if any, else SmfPluginErrNone
+	 * @param aGroup [in] the group in which to search
+	 * @param aContact [in] The contact to be searched, 
+	 * default (NULL) is the self contact.
+	 * @param aPageNum [in] The page to be extracted
+	 * @param aItemsPerPage [in] Number of items per page
+	 * @return Appropriate value of the enum SmfPluginError.
+	 * Plugin error if any, else SmfPluginErrNone for success
 	 */
 	virtual SmfPluginError searchInGroup( SmfPluginRequestData &aRequest,